@@ -6,10 +6,13 @@ make clean
 
 make dist
 
+. automation/set_release_suffix.sh
+
 # create the src.rpm, assuming the tarball is in the project's directory
 rpmbuild \
     -D "_srcrpmdir $PWD/output" \
     -D "_topmdir $PWD/rpmbuild" \
+    ${release_suffix:+-D "release_suffix ${release_suffix}"} \
     -ts ./*.gz
 
 # install any build requirements
@@ -19,6 +22,7 @@ yum-builddep output/*src.rpm
 rpmbuild \
     -D "_rpmdir $PWD/output" \
     -D "_topmdir $PWD/rpmbuild" \
+    ${release_suffix:+-D "release_suffix ${release_suffix}"} \
     --rebuild output/*.src.rpm
 
 # Store any relevant artifacts in exported-artifacts for the ci system to
